yakumo.neutron.v2.quota

Package yakumo :: Package neutron :: Package v2 :: Module quota |
[hide private]
[frames] | no frames]

# Module quota

source code

Resource class and its manager for quotas in Networking V2 API

Classes | [hide private]
| Resource Resource class for quotas in Networking V2 API
| Manager Manager class for quotas in Networking V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``project``'``,` `'``tenant_id``'``,` <yakumo.mapper.R`...``
| __package__ = ``'``yakumo.neutron.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('project',
        'tenant_id',
        <yakumo.mapper.Resource object at 0x7f1333c44c90>),
       ('subnet',
        'subnet',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('ikepolicy',
        'ikepolicy',
      ...